@@ -37,7 +37,7 @@
 
 #define VERLINES 7							/* number of lines in this vanity text */
 #define VER1 "## dgamelaunch - network console game launcher\n"
-#define VER2 "## version 1.2.21\n"
+#define VER2 "## version 1.3.3\n"
 #define VER3 "## \n"
 #define VER4 "## (c)2001-3 M. Drew Streib. This program's source is released under the GPL.\n"
 #define VER5 "## Send mail to <dtype@dtype.org> for details or a copy of the source code.\n"
@@ -201,7 +201,9 @@ inprogressmenu ()
 			mvaddstr (1, 1, VER1);
 			mvaddstr (3, 1,
 								"(Press 'q' during game playback to return to this menu.)");
-			mvaddstr (4, 1, "The following games are in progress:");
+			mvaddstr (4, 1,
+								"(Use capital letter of selection to strip DEC graphics, VERY experimental!)");
+			mvaddstr (5, 1, "The following games are in progress:");
 
 			/* clean old games and list good ones */
 			i = 0;
@@ -209,7 +211,7 @@ inprogressmenu ()
 			if (!pdir)
 				exit (140);
 
-			while ((pdirent = readdir (pdir)) && (i <= 15))
+			while ((pdirent = readdir (pdir)) && (i <= 14))
 				{
 					strcpy (fullname, LOC_INPROGRESSDIR);
 					strncat (fullname, pdirent->d_name, 100);
@@ -243,7 +245,7 @@ inprogressmenu ()
 													 i + 97, m_name, m_date, m_time,
 													 (time (&ctime) - pstat.st_mtime) / 60,
 													 (time (&ctime) - pstat.st_mtime) % 60);
-									mvaddstr (6 + i++, 1, printline);
+									mvaddstr (7 + i++, 1, printline);
 								}
 						}
 					else
@@ -272,7 +274,24 @@ inprogressmenu ()
 					clear ();
 					refresh ();
 					endwin ();
-					ttyplay_main (ttyrecname, 1);
+					ttyplay_main (ttyrecname, 1, 0);
+				}
+
+			/* capital lettter. experimental */
+			if ((menuchoice - 65) >= 0 && (menuchoice - 65) < i)
+				{
+					/* valid choice has been made */
+					strcpy (ttyrecname, LOC_TTYRECDIR);
+					strncat (ttyrecname, games[menuchoice - 65], 100);
+					replacestr = strstr (ttyrecname, ":");
+					if (!replacestr)
+						exit (145);
+					replacestr[0] = '/';
+
+					clear ();
+					refresh ();
+					endwin ();
+					ttyplay_main (ttyrecname, 1, 1);
 				}
 
 			closedir (pdir);
