@@ -88,9 +88,20 @@ int
 read_header (FILE * fp, Header * h)
 {
 	int buf[3];
+	int numread;
+	long offset;
 
-	if (fread (buf, sizeof (int), 3, fp) < 3)
+	offset = ftell (fp);
+	numread = fread (buf, sizeof (int), 3, fp);
+
+	if (numread == 0)
+		return 0;
+
+	/* odd but possible race condition when full header isn't read because
+	 * it isn't there yet. */
+	if (numread < 3)
 		{
+			fseek (fp, offset, SEEK_SET);
 			return 0;
 		}
 
@@ -98,12 +109,6 @@ read_header (FILE * fp, Header * h)
 	h->tv.tv_usec = convert_to_little_endian (buf[1]);
 	h->len = convert_to_little_endian (buf[2]);
 
-	/* one day I hope to not need this */
-	if (h->len > 4096) 
-		{
-			return 0;
-		}
-
 	return 1;
 }
 
